@@ -112,14 +112,17 @@ def membership_search(request, template_name="memberships/search.html"):
 
 
 @login_required
-@superuser_required
 def membership_details(request, id=0, template_name="memberships/details.html"):
     """
     Membership details.
     """
     membership = get_object_or_404(MembershipDefault, pk=id)
 
-    if not has_perm(request.user, 'memberships.view_membership', membership):
+    super_user_or_owner = (
+        request.user.profile.is_superuser,
+        request.user == membership.user)
+
+    if not any(super_user_or_owner):
         raise Http403
 
     EventLog.objects.log(instance=membership)
@@ -1632,7 +1635,9 @@ def membership_default_add(request, slug='',
             'department': user.profile.department,
         }
 
-    profile_form = ProfileForm(app_fields, request.POST or None,
+    profile_form = ProfileForm(
+        app_fields,
+        request.POST or None,
         initial=profile_initial
     )
 
@@ -1717,10 +1722,9 @@ def membership_default_add(request, slug='',
 
                 user = user_form.save()
 
-                profile_form.instance = user.profile
-                profile_form.save(
-                    request_user=request.user
-                )
+                if hasattr(user, 'profile'):
+                    profile_form.instance = user.profile
+                    profile_form.save(request_user=request.user)
 
                 # save demographics
                 demographics = demographics_form.save(commit=False)
